import { ContentTypeEnum } from '@/enums/httpEnums'
import { defHttp } from '@/utils/axios/index'
import type { ApiResult } from '../model/baseModel'
import type { ResourceFieldDto, ResourceRepositoryTreeDto } from './model/repositoryModel'

export type ResourceSaveParamsDto = Omit<ResourceRepositoryTreeDto, 'childNode'>

enum Api {
  REPOSITORY_LIST = '/resource/findList',
  GET_RESOURCE_FIELD = '/resourceField/getResourceField',
  GET_RESOURCE_FIELD_VALUE = '/resourceField/getResourceFieldValue',
  FIND_PARENT_RESOURCE = '/resource/findParentResourceTypeAndFields',
  RESOURCE_SAVE = '/resource/save'
}

export const apiGetRepositoryList = () => {
  return defHttp.get<ApiResult<ResourceRepositoryTreeDto[]>>({
    url: Api.REPOSITORY_LIST,
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}

export const apiGetResourceField = (resourceTypeId: string) => {
  return defHttp.get<ApiResult<ResourceFieldDto[]>>({
    url: Api.GET_RESOURCE_FIELD,
    params: { resourceTypeId },
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}

export const apiGetResourceFieldValue = (resourceTypeId: string) => {
  return defHttp.get<ApiResult<Recordable[]>>({
    url: Api.GET_RESOURCE_FIELD_VALUE,
    params: { resourceTypeId },
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}

export const apiFindParentResource = (tableName: string) => {
  return defHttp.get<ApiResult<ResourceRepositoryTreeDto>>({ 
    url: Api.FIND_PARENT_RESOURCE,
    params: { tableName },
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}

export const apiResourceSave = (data: ResourceSaveParamsDto) => {
  return defHttp.post<ApiResult<ResourceRepositoryTreeDto>>({ 
    url: Api.RESOURCE_SAVE,
    data
  })
}
