import type { ResourceRepositoryTreeDto } from '@/api/resource/model/repositoryModel'
import { apiGetRepositoryList } from '@/api/resource/repository'
import { onMounted, reactive, ref, unref, watch } from 'vue'
import mitter from '@/utils/eventBus'
import type { ElTree, TreeNode } from 'element-plus'

export function useRepositoryTree() {
  const fieldNames = reactive({
    children: 'childNode',
    title: 'resourceTableTitle',
    key: 'resourceTypeId'
  })
  const treeLoading = ref(false)
  const treeRef = ref<InstanceType<typeof ElTree>>()
  const searchText = ref('')
  const selectedNodeData = reactive<Recordable>({})
  const openNode = reactive<Recordable>({})
  const selectedKey = ref<(string | number)>('')
  const treeList = ref<ResourceRepositoryTreeDto[]>([])
  const open = ref(false)

  watch(searchText, (val) => {
    treeRef.value?.filter(val)
  })

  const filterNode = (value: string, data: Recordable) => {
    if (!value) return true
    return data.resourceTableTitle.includes(value)
  }

  const getTreeList = async () => {
    const { result } = await apiGetRepositoryList()
    treeList.value = result
    // 设置默认选中第一个
    onSelect([result[0]])
  }

  // const onSelect = (keys: (string | number)[], e?: any) => {
  const onSelect = (node: any) => {

    node && Object.assign(selectedNodeData, unref(node))
    selectedKey.value = node.resourceTypeId
    // 触发 表格 查询
    mitter.emit('treeSelect', {
      key: unref(selectedKey),
      node: unref(node)
    })
  }

  const onContextMenuClick = (key: any, data: any) => {
    console.log('data', data)
    Object.assign(openNode, unref(data))
    open.value = true
  }

  onMounted(async () => {
    treeLoading.value = true
    await getTreeList()
    treeLoading.value = false
  })

  return {
    open,
    treeRef,
    treeLoading,
    searchText,
    openNode,
    fieldNames,
    treeList,
    selectedKey,
    onSelect,
    filterNode,
    onContextMenuClick
  }
}
